@@ -45,35 +45,33 @@ run_apport(TrayApplet *ta)
        return g_spawn_command_line_async(CRASHREPORT_REPORT_APP, NULL);
 }
 
-static gint
+static gboolean
 show_notification (TrayApplet *ta)
 {
-	NotifyNotification *n;
-	int                 x, y;
+   NotifyNotification *n;
 
-	// only show once the icon is realy availabe
-	if(!GTK_WIDGET_REALIZED(ta->tray_icon))
-	   return TRUE;
+   GdkRectangle area;
+   gtk_status_icon_get_geometry(ta->tray_icon, NULL, &area, NULL);
 
-	/* Get the location of the icon.  If there's no location, come back
-	 * in a few seconds. */
-	gdk_window_get_origin (GTK_WIDGET(ta->tray_icon)->window, &x, &y);
-	if ((x <= 0) || (y <= 0))
-		return TRUE;
+   // no usefull coordiante yet, do another timeout
+   if(area.x <= 0 || area.y <= 0 || area.width <= 0 || area.height <= 0)
+      return TRUE;
 
-	/* Check whether the icon is still visible, may have gone away */
-	if (!GTK_WIDGET_VISIBLE (ta->tray_icon))
-		return FALSE;
+   // check if the update-icon is still visible (in the delay time a 
+   // update may already have been performed)
+   if(!gtk_status_icon_get_visible(ta->tray_icon))
+      return FALSE;
 
-	/* Create and show the notification */
-	n = notify_notification_new (_("Crash report detected"),
+   // now show a notification handle 
+   n = notify_notification_new_with_status_icon(
+				     _("Crash report detected"),
 				     _("An application has crashed on your "
 				       "system (now or in the past). "
 				       "Click on the notification icon to "
 				       "display details. "
 				       ),
 				     GTK_STOCK_DIALOG_INFO,
-				     GTK_WIDGET(ta->tray_icon));
+				     ta->tray_icon);
 	notify_notification_set_timeout (n, 60000);
 	notify_notification_show (n, NULL);
 	g_object_set_data (G_OBJECT(ta->tray_icon), "notification", n);
@@ -86,8 +84,7 @@ hide_crash_applet(TrayApplet *ta)
 {
    NotifyNotification *n;
  
-   gtk_widget_hide (GTK_WIDGET(ta->tray_icon));
-   gtk_widget_unrealize (GTK_WIDGET(ta->tray_icon));
+   gtk_status_icon_set_visible(ta->tray_icon, FALSE);
    
    /* Hide any notification popup */
    n = g_object_get_data (G_OBJECT(ta->tray_icon), "notification");
@@ -99,9 +96,6 @@ hide_crash_applet(TrayApplet *ta)
 gboolean
 crashreport_check (TrayApplet *ta)
 {
-   GDir* dir;
-   struct stat buf;
-   const gchar *crashreport, *s;
    int crashreports_found = 0;
    static gboolean first_run = TRUE;
    gboolean system_crashes;
@@ -133,19 +127,14 @@ crashreport_check (TrayApplet *ta)
 
    // crashreport found and first run: show notification bubble and
    // return
-   gboolean visible = GTK_WIDGET_VISIBLE(GTK_WIDGET(ta->tray_icon));
+   gboolean visible = gtk_status_icon_get_visible(ta->tray_icon);
 
    //   g_print("reports: %i, visible: %i\n",crashreports_found,visible);
 
    if((crashreports_found > 0) && (system_crashes || first_run)) {
-      gtk_tooltips_set_tip (GTK_TOOLTIPS(ta->tooltip),
-			    GTK_WIDGET (ta->eventbox),
-			    _("Crash report detected"),
-			    _("Click on the notification icon to "
-			      "display details. "));
-
-      gtk_widget_show (GTK_WIDGET(ta->tray_icon));
-      
+      gtk_status_icon_set_tooltip(ta->tray_icon,
+				  _("Crash report detected"));
+      gtk_status_icon_set_visible(ta->tray_icon, TRUE);
       /* Show the notification, after a delay so it doesn't look ugly
        * if we've just logged in */
       g_timeout_add(5000, (GSourceFunc)(show_notification), ta);
@@ -168,14 +157,10 @@ crashreport_check (TrayApplet *ta)
 
 static gboolean
 button_release_cb (GtkWidget *widget,
-		   GdkEventButton *event,
 		   TrayApplet *ta)
 {
-	if ((event->button == 1) && (event->type == GDK_BUTTON_RELEASE)) {
-		// fire up the crashreport tool
-	   run_apport(ta);
-	   hide_crash_applet(ta);
-	}
+run_apport(ta);
+hide_crash_applet(ta);
 	return TRUE;
 }
 
@@ -183,11 +168,10 @@ button_release_cb (GtkWidget *widget,
 void
 crashreport_tray_icon_init (TrayApplet *ta)
 {
-	GtkWidget *widget;
 
 	ta->user_data = gconf_client_get_default();
         g_signal_connect (G_OBJECT(ta->tray_icon),
-			  "button-release-event",
+			  "activate",
 			  G_CALLBACK (button_release_cb),
 			  ta);
 
