@@ -2,6 +2,7 @@
 #include "config.h"
 #endif
 
+#include <fcntl.h>
 #include <glib.h>
 #include <gtk/gtk.h>
 #include <glib/gstdio.h>
@@ -39,16 +40,12 @@ static void debug_log_handler (const gchar   *log_domain,
 
 void hooks_trayicon_update_tooltip (TrayApplet *un, int num_hooks)
 {
-   g_debug("update_tooltip: %x ", un);
+   g_debug("update_tooltip: %p ", un);
    gchar *updates;
-   gchar *explanation;
 
-   updates = _("Information about newly installed packages available");
-   explanation = _("Click on the notification icon to show the information");
+   updates = _("Information available");
 
-   gtk_tooltips_set_tip(GTK_TOOLTIPS(un->tooltip), 
-			GTK_WIDGET (un->eventbox), 
-			updates, explanation);
+   gtk_status_icon_set_tooltip(un->tray_icon, updates);
 }
 
 
@@ -143,12 +140,12 @@ gboolean hook_file_mark_as_seen(HookTrayAppletPrivate *priv,
       HookFile *e = (HookFile*)elm->data;
       g_debug("will write out: %s (%s)",e->filename, e->md5);
       if(e->seen == TRUE) {
-	 g_debug("e->seen: %s %i %x", e->filename,e->mtime, (int)(e->cmd_run));
-	 fprintf(f,"%s %i %x\n", e->filename, e->mtime, (int)(e->cmd_run));
+	 g_debug("e->seen: %s %li %x", e->filename,e->mtime, (int)(e->cmd_run));
+	 fprintf(f,"%s %li %x\n", e->filename, e->mtime, (int)(e->cmd_run));
       } else if(memcmp(e->md5,md5,16) == 0) {
 	 e->seen = TRUE;
-	 fprintf(f,"%s %i %x\n", e->filename,hf->mtime, (int)(e->cmd_run));
-	 g_debug("same md5: %s %i %x",e->filename,hf->mtime,(int)(e->cmd_run));
+	 fprintf(f,"%s %li %x\n", e->filename,hf->mtime, (int)(e->cmd_run));
+	 g_debug("same md5: %s %li %x",e->filename,hf->mtime,(int)(e->cmd_run));
       }
    }
 
@@ -252,6 +249,8 @@ gboolean show_next_hook(TrayApplet *ta, GList *hooks)
    HookTrayAppletPrivate *priv = (HookTrayAppletPrivate *)ta->user_data;
    GladeXML *xml = priv->glade_xml;
 
+   GtkWidget *title = glade_xml_get_widget(xml, "label_title");
+   assert(title);
    GtkWidget *text = glade_xml_get_widget(xml, "textview_hook");
    assert(text);
    GtkWidget *button_next = glade_xml_get_widget(xml, "button_next");
@@ -302,7 +301,12 @@ gboolean show_next_hook(TrayApplet *ta, GList *hooks)
    } else {
       gtk_widget_hide(button_run);
    }
-
+   char *title_str = hook_file_lookup_i18n(rfc822, "Title");
+   if(title_str != NULL) {
+      gchar *s = g_strdup_printf("<span weight=\"bold\" size=\"larger\">%s</span>", title_str);
+      gtk_label_set_markup(GTK_LABEL(title), s);
+      g_free(s);
+   }
    char *summary = hook_description_get_summary(rfc822);
    char *descr = hook_description_get_description(rfc822);
    char *s = g_strdup_printf("%s\n\n%s\n",gettext(summary), gettext(descr));
@@ -417,21 +421,18 @@ void show_hooks(TrayApplet *ta)
 
 static gboolean
 button_release_cb (GtkWidget *widget, 
-		   GdkEventButton *event, 
 		   TrayApplet *ta)
 {
    HookTrayAppletPrivate *priv = (HookTrayAppletPrivate*)ta->user_data;
 
-	if (event->button == 1 && event->type == GDK_BUTTON_RELEASE) {
-	   if(priv->active_notification != NULL) {
-	      notify_notification_close(priv->active_notification, NULL);
-	      priv->active_notification = NULL;
-	   }
-		 
-	   //g_debug("left click on hook applet\n");
-	   show_hooks(ta);
-	}
-	return TRUE;
+   if(priv->active_notification != NULL) {
+      notify_notification_close(priv->active_notification, NULL);
+      priv->active_notification = NULL;
+   }
+   
+   //g_debug("left click on hook applet\n");
+   show_hooks(ta);
+   return TRUE;
 }
 
 gboolean is_hook_relevant(const gchar *hook_file)
@@ -467,8 +468,8 @@ gboolean is_hook_relevant(const gchar *hook_file)
       time_t mtime = hook_file_time(hook_file);
       time_t now = time(NULL);
 
-      g_debug("now: %i mtime: %i uptime: %f",now,mtime,uptime);
-      g_debug("diff: %i  uptime: %f",now-mtime,uptime);
+      g_debug("now: %li mtime: %li uptime: %f",now,mtime,uptime);
+      g_debug("diff: %li  uptime: %f",now-mtime,uptime);
       if((int)uptime > 0 && (now - mtime) > (int)uptime) {
 	 g_debug("not relevant because of reboot: %s",hook_file);
 	 res = FALSE;
@@ -498,15 +499,22 @@ static gboolean show_notification(void *data)
 
    GtkWidget *d = glade_xml_get_widget(priv->glade_xml,"dialog_hooks");
    if((d && GTK_WIDGET_VISIBLE(d)) || priv->active_notification != NULL)
-      return;
+      return FALSE;
+
+   GdkRectangle area;
+   gtk_status_icon_get_geometry(ta->tray_icon, NULL, &area, NULL);
+   // no usefull coordiante yet, do another timeout
+   if(area.x <= 0 || area.y <= 0 || area.width <= 0 || area.height <= 0)
+      return TRUE;
 
    NotifyNotification *n;
    GdkPixbuf* pix;
-   n = notify_notification_new(_("Information about newly installed packages available\n"),
+   n = notify_notification_new_with_status_icon(
+			       _("Information available"),
 			       _("Click on the notification icon"
 				 " to show the available information.\n"),
 			       NULL, 
-			       GTK_WIDGET(ta->tray_icon));
+			       ta->tray_icon);
    
    pix = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), 
 				  GTK_STOCK_DIALOG_INFO, 48,0,NULL);
@@ -515,19 +523,20 @@ static gboolean show_notification(void *data)
    notify_notification_set_timeout (n, 60*1000);
    notify_notification_show(n, NULL);
    priv->active_notification = n;
-   
+
    return FALSE;
 }
 
 gboolean check_update_hooks(TrayApplet *ta)
 {
-   g_debug("check_update_hooks()");
-
-   HookTrayAppletPrivate *priv = (HookTrayAppletPrivate*)ta->user_data;
-
+   GList *elm;
+   HookFile *hf;
    GDir* dir;
    const gchar *hook_file;
 
+   g_debug("check_update_hooks()");
+   HookTrayAppletPrivate *priv = (HookTrayAppletPrivate*)ta->user_data;
+
    dir=g_dir_open(HOOKS_DIR, 0, NULL);
    if(dir == NULL) {
       g_warning("can't read %s directory\n",HOOKS_DIR);
@@ -545,7 +554,7 @@ gboolean check_update_hooks(TrayApplet *ta)
 	 continue;
       }
       // see if we already know about this hook filename
-      GList *elm = g_list_find_custom(priv->hook_files,hook_file,
+      elm = g_list_find_custom(priv->hook_files,hook_file,
 				      compare_hook_func);
 
       // not seen before, add to the list
@@ -557,7 +566,7 @@ gboolean check_update_hooks(TrayApplet *ta)
 	 hook_file_md5(hook_file, t->md5);
 	 t->cmd_run = FALSE;
 	 t->seen = FALSE;
-	 priv->hook_files = g_list_append(priv->hook_files, t);
+	 priv->hook_files = g_list_append(priv->hook_files, (gpointer)t);
 	 // init elm with the just added record (will be needed below)
 	 elm = g_list_find_custom(priv->hook_files,hook_file,
 				  compare_hook_func);
@@ -566,12 +575,12 @@ gboolean check_update_hooks(TrayApplet *ta)
       
       // this is the hook file information we have (either because it was
       // availabe already or because we added it)
-      HookFile *hf = (HookFile*)elm->data;
+      hf = (HookFile*)elm->data;
 
       // file has changed since we last saw it
       time_t new_mtime = hook_file_time(hook_file);
       if(new_mtime > hf->mtime) {
-	 g_debug("newer mtime: %s (%i > %i))",hook_file, new_mtime, hf->mtime);
+	 g_debug("newer mtime: %s (%li > %li))",hook_file, new_mtime, hf->mtime);
 	 hf->seen = FALSE;
       }
 
@@ -609,9 +618,6 @@ gboolean check_update_hooks(TrayApplet *ta)
 	 }
       } else 
 	 g_debug("already seen: '%s'",hook_file);
-      
-
-
    }
    g_dir_close(dir);
 
@@ -622,22 +628,20 @@ gboolean check_update_hooks(TrayApplet *ta)
    assert(button_next);
 
    // show a notification
-   if(unseen_count > 0 && !GTK_WIDGET_VISIBLE(ta->tray_icon)) {
+   if(unseen_count > 0 && !gtk_status_icon_get_visible (ta->tray_icon))
       g_timeout_add(5000, show_notification, ta);
-   }
 
    switch(unseen_count) {
    case 0:
-      gtk_widget_hide(GTK_WIDGET(ta->tray_icon));
-      gtk_widget_unrealize (GTK_WIDGET(ta->tray_icon));
+      gtk_status_icon_set_visible (ta->tray_icon, FALSE);
       gtk_widget_hide(button_next);
       break;
    case 1:
-      gtk_widget_show(GTK_WIDGET(ta->tray_icon));
+      gtk_status_icon_set_visible (ta->tray_icon, TRUE);
       gtk_widget_hide(button_next);
       break;
    default:
-      gtk_widget_show(GTK_WIDGET(ta->tray_icon));
+      gtk_status_icon_set_visible (ta->tray_icon, TRUE);
       gtk_widget_show(button_next);
       break;
    }
@@ -648,6 +652,7 @@ gboolean check_update_hooks(TrayApplet *ta)
 
 void hook_read_seen_file(HookTrayAppletPrivate *priv, const char* filename)
 {
+   HookFile *t;
    char buf[512];
    int time, was_run;
    FILE *f = fopen(filename, "r");
@@ -693,14 +698,14 @@ void hook_read_seen_file(HookTrayAppletPrivate *priv, const char* filename)
 	 // not in the list yet
 	 // add the just read hook file to the list
 	 g_debug("got: %s %i %i ",buf,time,was_run);
-	 HookFile *t = g_new0(HookFile, 1);
+	 t = g_new0(HookFile, 1);
 	 t->filename = strdup(buf);
 	 t->mtime = time;
 	 t->cmd_run = was_run;
 	 t->seen = TRUE;
 	 hook_file_md5(t->filename,t->md5);
 
-	 priv->hook_files = g_list_append(priv->hook_files, t);
+	 priv->hook_files = g_list_append(priv->hook_files, (gpointer)t);
       }
    }
    fclose(f);
@@ -736,8 +741,7 @@ on_insert_text(GtkTextBuffer *buffer,
 	       gint           arg3,
 	       gpointer       user_data)
 {
-   GtkTextIter iter, match_start, match_end, match_tmp, iter_real_end;
-   gboolean ret;
+   GtkTextIter iter, match_start, match_end, match_tmp;
 
    // get where we start
    gtk_text_buffer_get_iter_at_offset(buffer, &iter,
@@ -823,7 +827,7 @@ void hook_tray_icon_init(TrayApplet *ta)
 
    /* show dialog on click */
    g_signal_connect (G_OBJECT(ta->tray_icon),
-		     "button-release-event",
+		     "activate",
 		     G_CALLBACK (button_release_cb),
 		     ta);
 
