@@ -2,27 +2,35 @@
 #define _HOOKS_H_
 
 
+// evil HACK
+extern int HOOK_DEBUG;
+
 gboolean check_update_hooks(TrayApplet *un);
 void hook_tray_icon_init(TrayApplet *un);
 
+
+
 typedef struct _HookFile HookFile;
 struct _HookFile
 {
    char *filename;
    time_t mtime;
-   char md5[16];
+   unsigned char md5[16];
    gboolean cmd_run;
    gboolean seen;
 };
 
 
-typedef struct _HookDialog HookDialog;
-struct _HookDialog
+typedef struct _HookTrayAppletPrivate HookTrayAppletPrivate;
+struct _HookTrayAppletPrivate
 {
    GladeXML *glade_xml;
 
    // the list of all hook files
    GList *hook_files;   
+
+   // the notification
+   NotifyNotification *active_notification;
 };
 
 #endif
