@@ -17,34 +17,31 @@
 
 static GladeXML *xml;
 
-static gint
+static gboolean
 show_notification (TrayApplet *ta)
 {
 	NotifyNotification *n;
-	int                 x, y;
 
-	// only show once the icon is realy availabe
-	if(!GTK_WIDGET_REALIZED(ta->tray_icon))
+	GdkRectangle area;
+	gtk_status_icon_get_geometry(ta->tray_icon, NULL, &area, NULL);
+
+	// no usefull coordiante yet, do another timeout
+	if(area.x <= 0 || area.y <= 0 || area.width <= 0 || area.height <= 0)
 	   return TRUE;
 
-	/* Get the location of the icon.  If there's no location, come back
-	 * in a few seconds. */
-	gdk_window_get_origin (GTK_WIDGET(ta->tray_icon)->window, &x, &y);
-	if ((x <= 0) || (y <= 0))
-		return TRUE;
-
-	/* Check whether the icon is still visible, may have gone away */
-	if (!GTK_WIDGET_VISIBLE (ta->tray_icon))
-		return FALSE;
+	// only show once the icon is realy availabe
+	if(!gtk_status_icon_get_visible(ta->tray_icon))
+	   return TRUE;
 
 	/* Create and show the notification */
-	n = notify_notification_new (_("System restart required"),
+	n = notify_notification_new_with_status_icon(
+				     _("System restart required"),
 				     _("To complete the update of your system, "
 				       "restart your system.\n\n"
 				       "Click on the notification icon to "
 				       "restart your system."),
 				     GTK_STOCK_DIALOG_WARNING,
-				     GTK_WIDGET(ta->tray_icon));
+				     ta->tray_icon);
 	notify_notification_set_timeout (n, 60000);
 	notify_notification_show (n, NULL);
 	g_object_set_data (G_OBJECT(ta->tray_icon), "notification", n);
@@ -61,9 +58,7 @@ reboot_check (TrayApplet *ta)
 	if (stat (REBOOT_FILE, &statbuf)) {
 		NotifyNotification *n;
 
-		gtk_widget_hide (GTK_WIDGET(ta->tray_icon));
-		gtk_widget_unrealize (GTK_WIDGET(ta->tray_icon));
-
+		gtk_status_icon_set_visible (ta->tray_icon, FALSE);
 		/* Hide any notification popup */
 		n = g_object_get_data (G_OBJECT(ta->tray_icon), "notification");
 		if (n)
@@ -74,16 +69,12 @@ reboot_check (TrayApplet *ta)
 	}
 
 	/* Skip the rest if the icon is already visible */
-	if (GTK_WIDGET_VISIBLE(GTK_WIDGET(ta->tray_icon)))
-		return TRUE;
+	if (gtk_status_icon_get_visible (ta->tray_icon))
+	   return TRUE;
 
-	gtk_tooltips_set_tip (GTK_TOOLTIPS(ta->tooltip),
-			      GTK_WIDGET (ta->eventbox),
-			      _("System restart required"),
-			      _("Click on the notification icon to "
-				"restart your computer"));
-
-	gtk_widget_show (GTK_WIDGET(ta->tray_icon));
+	gtk_status_icon_set_tooltip (ta->tray_icon,  
+				     _("System restart required"));
+	gtk_status_icon_set_visible (ta->tray_icon, TRUE);
 
 	/* Check whether the user doesn't like notifications */
 	if (gconf_client_get_bool ((GConfClient*) ta->user_data,
@@ -122,20 +113,16 @@ request_reboot (void)
 
 static gboolean
 button_release_cb (GtkWidget *widget,
-		   GdkEventButton *event,
 		   TrayApplet *ta)
 {
-	if ((event->button == 1) && (event->type == GDK_BUTTON_RELEASE)) {
-		GtkWidget *dia;
+   GtkWidget *dia;
+   
+   dia = glade_xml_get_widget (xml, "dialog_reboot");
+   if (gtk_dialog_run (GTK_DIALOG(dia)) == GTK_RESPONSE_OK)
+      request_reboot ();
+   gtk_widget_hide (dia);
 
-		dia = glade_xml_get_widget (xml, "dialog_reboot");
-		if (gtk_dialog_run (GTK_DIALOG(dia)) == GTK_RESPONSE_OK)
-			request_reboot ();
-
-		gtk_widget_hide (dia);
-	}
-
-	return TRUE;
+   return TRUE;
 }
 
 
@@ -143,7 +130,6 @@ void
 reboot_tray_icon_init (TrayApplet *ta)
 {
 	GtkWidget *widget;
-	GtkImage *image;
 
 	xml = glade_xml_new (GLADEDIR"reboot-dialog.glade", NULL, NULL);
 
@@ -155,7 +141,7 @@ reboot_tray_icon_init (TrayApplet *ta)
 	ta->user_data = gconf_client_get_default();
 
         g_signal_connect (G_OBJECT(ta->tray_icon),
-			  "button-release-event",
+			  "activate",
 			  G_CALLBACK (button_release_cb),
 			  ta);
 
