@@ -29,6 +29,8 @@
 #include <grp.h>
 #include <pwd.h>
 #include <limits.h>
+#include <glib.h>
+#include <glib/gstdio.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 #include <libgnomevfs/gnome-vfs.h>
@@ -36,15 +38,16 @@
 #include <libgnomevfs/gnome-vfs-monitor.h>
 
 #include "update-notifier.h"
-#include "eggtrayicon.h"
 #include "hal.h"
 #include "update.h"
 #include "hooks.h"
+#include "reboot.h"
+#include "crash.h"
+#include "avahi.h"
 
 /* some prototypes */
 extern gboolean up_get_clipboard (void);
 gboolean update_timer_finished(gpointer data);
-static void tray_destroyed_cb(GtkWidget *widget, void *data);
 
 // the time when we check for fam events
 #define TIMEOUT_FAM 1000*5 /* 5 sec */
@@ -86,29 +89,11 @@ gboolean
 trayapplet_create (TrayApplet *un, char *name)
 {
         //g_print("trayicon_create()\n");
-	GdkPixbuf *pixbuf;
-
-	GtkIconTheme* icon_theme = gtk_icon_theme_get_default();
 
 	/* setup widgets */
-        un->tooltip = gtk_tooltips_new ();
-	un->tray_icon = egg_tray_icon_new (name);
-	un->eventbox = gtk_event_box_new ();
-	gtk_widget_show(un->eventbox);
-	un->icon = gtk_image_new ();
-	gtk_widget_show(un->icon);
-
-	/* load icon */
-	pixbuf = gtk_image_get_pixbuf (GTK_IMAGE(un->icon));
-	if (pixbuf)
-		g_object_unref (G_OBJECT (pixbuf));
-	pixbuf = gtk_icon_theme_load_icon (icon_theme, name,
-					   16, 0,NULL);
-	gtk_image_set_from_pixbuf (GTK_IMAGE (un->icon), pixbuf);
-
-	/* build container */
-	gtk_container_add (GTK_CONTAINER (un->eventbox), un->icon);
-	gtk_container_add (GTK_CONTAINER (un->tray_icon), un->eventbox);
+	un->tray_icon = gtk_status_icon_new_from_icon_name (name);
+	un->name = name;
+	gtk_status_icon_set_visible (un->tray_icon, FALSE);
 
 	return TRUE;
 }
@@ -133,7 +118,6 @@ monitor_cb(GnomeVFSMonitorHandle *handle,
 	   gpointer user_data)
 {
    UpgradeNotifier *un = (UpgradeNotifier*)user_data;
-   int i;
 
 #if 0
    g_print("monitor_uri: %s\n", monitor_uri);
@@ -337,10 +321,6 @@ tray_icons_init(UpgradeNotifier *un)
    trayapplet_create(un->update, "updates-notifier");
    update_tray_icon_init(un->update);
 
-   /* a destroy signal handler (e.g. when the gnome-panel is restarted */
-   g_signal_connect(G_OBJECT(un->update->tray_icon), "destroy", 
-		    G_CALLBACK(tray_destroyed_cb), un);
-
    /* update hook icon*/
    un->hook = g_new0 (TrayApplet, 1);
    trayapplet_create(un->hook, "hook-notifier");
@@ -359,14 +339,6 @@ tray_icons_init(UpgradeNotifier *un)
    return FALSE; // for the tray_destroyed_cb
 }
 
-static void
-tray_destroyed_cb(GtkWidget *widget, void *data)
-{
-   g_debug("tray_destoryed_cb");
-   // try re-init on destroy
-   g_timeout_add(5000, (GSourceFunc)(tray_icons_init), data);
-}
-
 // this function checks if the user is in the admin group
 // if there is no admin group, we return true becuase there
 // is no way to figure if the user is a admin or not
@@ -389,6 +361,7 @@ in_admin_group()
    }
    for(i=0;i<ng;i++) {
       if(groups[i] == grp->gr_gid) {
+	 free(groups);
 	 return TRUE;
       }
    }
@@ -415,13 +388,11 @@ main (int argc, char *argv[])
 	GOptionContext *context;
 	context = g_option_context_new (" - inform about updates");
 	g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
-
 	gnome_program_init (PACKAGE, PACKAGE_VERSION, 
 			    LIBGNOMEUI_MODULE,
 			    argc, argv, 
 			    GNOME_PARAM_GOPTION_CONTEXT, context,
 			    GNOME_PARAM_NONE);
-
 	notify_init("update-notifier");
         bindtextdomain(PACKAGE, PACKAGE_LOCALE_DIR);
         bind_textdomain_codeset(PACKAGE, "UTF-8");
@@ -463,7 +434,8 @@ main (int argc, char *argv[])
 	g_free(dirname);
 
 	// create the icons with a timeout
-	g_timeout_add(5000, (GSourceFunc)(tray_icons_init), un);
+	//g_timeout_add(5000, (GSourceFunc)(tray_icons_init), un);
+	tray_icons_init(un);
 
         // initial check for avahi
         avahi_disabled_check();
