@@ -23,7 +23,6 @@
 #include <gnome.h>
 #include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
-#include "eggtrayicon.h"
 
 #define CLIPBOARD_NAME 	"UPGRADE_NOTIFIER_SELECTION"
 #define GCONF_KEY_DEFAULT_ACTION "/apps/update-notifier/default_action"
@@ -44,12 +43,9 @@ gboolean in_admin_group();
 typedef struct _TrayApplet TrayApplet;
 struct _TrayApplet 
 {
-   EggTrayIcon *tray_icon;
-   GtkWidget *icon;
-   GtkWidget *eventbox;
-   GtkTooltips *tooltip;
+   GtkStatusIcon *tray_icon;
    GtkWidget *menu;
-
+   char *name;
    void *user_data;
 };
 
