@@ -18,8 +18,9 @@ char* actions[][4] = {
 
    { "/usr/sbin/synaptic --dist-upgrade-mode --non-interactive --hide-main-window -o Synaptic::AskRelated=true",
      N_("Install all updates"), "/usr/share/applications/synaptic.desktop", TRUE
- },
-   { "/usr/sbin/synaptic --update-at-startup --non-interactive --hide-main-window", N_("Check for updates"), "/usr/share/applications/synaptic.desktop", TRUE },
+   },
+   { "/usr/sbin/synaptic --update-at-startup --non-interactive --hide-main-window", 
+     N_("Check for updates"), "/usr/share/applications/synaptic.desktop", TRUE },
    { "/usr/sbin/synaptic", N_("Start package manager"), 
      "/usr/share/applications/synaptic.desktop", TRUE},
    { NULL, NULL, NULL }
@@ -29,84 +30,26 @@ char* actions[][4] = {
 enum { NOTIFICATION_DEFAULT, NOTIFICATION_IGNORE, NOTIFICATION_SHOW_UPDATES };
 
 static gboolean
-button_release_cb (GtkWidget *widget, 
-		   GdkEventButton *event, 
-		   TrayApplet *ta)
+activate_cb (GtkWidget *widget, 
+	     TrayApplet *ta)
 {
-   UpdateTrayAppletPrivate *priv = (UpdateTrayAppletPrivate*)ta->user_data;
-
-   int index;
-   GTimeVal current_time;
-   static GTimeVal last_launch = { 0, 0 };
-
-   if (event->button == 1 && event->type == GDK_BUTTON_RELEASE) {
-      if(priv->active_notification != NULL) {
-	 notify_notification_close(priv->active_notification, NULL);
-	 priv->active_notification = NULL;
-      }
-
-/*       index = gconf_client_get_int(priv->gconf, */
-/* 				   GCONF_KEY_DEFAULT_ACTION,  */
-/* 				   NULL); */
-      index = 0;
-      //g_print("%s %s\n",actions[index][0],actions[index][1]);
-
-      // work around double clicking people by delaying clicks for 2
-      // seconds - FIXME: make this go away by using dbus
-      g_get_current_time(&current_time);
-      if(last_launch.tv_sec == 0 || (current_time.tv_sec - last_launch.tv_sec > 2)) {
-	 last_launch.tv_sec = current_time.tv_sec;
-	 //g_print("%s %s\n",actions[index][0],actions[index][1]);
-	 invoke (actions[index][0], actions[index][2], actions[index][3]);
-      }
-   }
+   int index = 0;
+   invoke (actions[index][0], actions[index][2], (long)actions[index][3]);
    return TRUE;
 }
 
-static void
-tray_popup_position_menu (GtkMenu  *menu,
-                          int      *x,
-                          int      *y,
-                          gboolean *push_in,
-                          gpointer  user_data)
-{
-        GtkWidget     *widget;
-        GtkRequisition requisition;
-        gint           menu_xpos;
-        gint           menu_ypos;
-
-        widget = GTK_WIDGET (user_data);
-
-        gtk_widget_size_request (GTK_WIDGET (menu), &requisition);
-
-        gdk_window_get_origin (widget->window, &menu_xpos, &menu_ypos);
-
-        menu_xpos += widget->allocation.x;
-        menu_ypos += widget->allocation.y;
-
-        if (menu_ypos > gdk_screen_get_height (gtk_widget_get_screen (widget)) / 2)
-                menu_ypos -= (requisition.height + 1);
-        else
-                menu_ypos += widget->allocation.height + 1;
-
-        *x = menu_xpos;
-        *y = menu_ypos;
-        *push_in = TRUE;
-}
-
 static gboolean
-button_press_cb (GtkWidget *widget,
-		 GdkEventButton *event,
-		 TrayApplet *un)
+popup_cb (GtkStatusIcon *status_icon,
+	  guint          button,
+	  guint          activate_time,
+	  TrayApplet     *un)
 {
-	if (event->button == 3) {
-	   gtk_menu_set_screen (GTK_MENU (un->menu),
-				gtk_widget_get_screen (GTK_WIDGET (un->tray_icon)));
-	   gtk_menu_popup (GTK_MENU (un->menu), NULL, NULL, 
-			   tray_popup_position_menu, widget,
-			   event->button, event->time);
-	}
-	return TRUE;
+   gtk_menu_set_screen (GTK_MENU (un->menu),
+			gtk_status_icon_get_screen(un->tray_icon));
+   gtk_menu_popup (GTK_MENU (un->menu), NULL, NULL, 
+		   gtk_status_icon_position_menu, un->tray_icon,
+		   button, activate_time);
+   return TRUE;
 }
 
 void
@@ -114,19 +57,12 @@ update_trayicon_update_tooltip (TrayApplet *ta, int num_upgrades)
 {
    //g_print("update_tooltip: %p %p %p\n", ta, ta->tooltip, ta->eventbox);
    gchar *updates;
-   gchar *explanation;
 
-   updates=g_strdup_printf(ngettext("There is %i update available",
-				    "There are %i updates available",
-				    num_upgrades),
-			   num_upgrades);
-   explanation = ngettext(
-           "Click on the notification icon to show the update",
-           "Click on the notification icon to show the updates", num_upgrades);
-
-   gtk_tooltips_set_tip(GTK_TOOLTIPS(ta->tooltip), 
-			GTK_WIDGET (ta->eventbox), 
-			updates, explanation);
+   updates = g_strdup_printf(ngettext("There is %i update available",
+				      "There are %i updates available",
+				      num_upgrades),
+			     num_upgrades);
+   gtk_status_icon_set_tooltip(ta->tray_icon, updates);
    g_free(updates);
 }
 
@@ -137,7 +73,7 @@ cb_action(GObject *self, void *user_data)
    TrayApplet *ta = user_data;
 	
    int i = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(self), "action"));
-   invoke (actions[i][0], _(actions[i][2]), actions[i][3]);
+   invoke (actions[i][0], _(actions[i][2]), (long)actions[i][3]);
 
    UpdateTrayAppletPrivate *priv = (UpdateTrayAppletPrivate*)ta->user_data;
    gconf_client_set_int(priv->gconf, GCONF_KEY_DEFAULT_ACTION, i, NULL);
@@ -214,17 +150,22 @@ void
 update_apt_is_running(TrayApplet *ta, gboolean is_running)
 {
    UpdateTrayAppletPrivate *priv = (UpdateTrayAppletPrivate*)ta->user_data;
+   //g_print("update_apt_is_running: %i\n",is_running);
 
-   //  we make the icon insensitive, because we can't make the
-   //  EggTrayIcon insensitive (otherwise we don't get a tooltip)
+   //  we load a different icon to show that apt is running
    // FIXME: we need block menu events
-   gtk_widget_set_sensitive(GTK_WIDGET(ta->icon), !is_running);
+   gchar *inactive_name = g_strdup_printf("%s-inactive", ta->name);
+   if(is_running)
+      gtk_status_icon_set_from_icon_name(ta->tray_icon, inactive_name);
+   else
+      gtk_status_icon_set_from_icon_name(ta->tray_icon, ta->name);
+
+   g_free(inactive_name);
    priv->apt_is_running = is_running;
 
    if(is_running) {
-      gtk_tooltips_set_tip(GTK_TOOLTIPS(ta->tooltip), 
-			   GTK_WIDGET (ta->eventbox),
-			   _("A package manager is working"),"");
+      gtk_status_icon_set_tooltip(ta->tray_icon,
+				  _("A package manager is working"));
       if(priv->active_notification != NULL) {
 	 notify_notification_close(priv->active_notification, NULL);
 	 priv->active_notification = NULL;
@@ -243,29 +184,26 @@ show_notification(gpointer user_data)
    if(priv->apt_is_running) 
       return TRUE;
 
-   // don't show anyting if the widget is not yet mapped
-   if(!GTK_WIDGET_REALIZED(ta->tray_icon))
-      return TRUE;
-
-   int x,y;
-   gdk_window_get_origin(GTK_WIDGET(ta->tray_icon)->window, &x, &y);
+   GdkRectangle area;
+   gtk_status_icon_get_geometry(ta->tray_icon, NULL, &area, NULL);
 
    // no usefull coordiante yet, do another timeout
-   if(x <= 0 || y <= 0)
+   if(area.x <= 0 || area.y <= 0 || area.width <= 0 || area.height <= 0)
       return TRUE;
 
    // check if the update-icon is still visible (in the delay time a 
    // update may already have been performed)
-   if(!GTK_WIDGET_VISIBLE(ta->tray_icon))
+   if(!gtk_status_icon_get_visible(ta->tray_icon))
       return FALSE;
 
    // now show a notification handle 
-   NotifyNotification *n = notify_notification_new(_("Software updates available"),
-						   _("Click on the notification"
-					             " icon to show the "
-						     "available updates.\n"),
-						   NULL, 
-						   GTK_WIDGET(ta->tray_icon));
+   NotifyNotification *n = notify_notification_new_with_status_icon(
+			      _("Software updates available"),
+			      _("Click on the notification"
+				" icon to show the "
+				"available updates.\n"),
+			      NULL, 
+			      ta->tray_icon);
  
    GdkPixbuf* pix= gtk_icon_theme_load_icon(gtk_icon_theme_get_default(), 
 					    GTK_STOCK_DIALOG_INFO, 48,0,NULL);
@@ -288,7 +226,6 @@ update_check (TrayApplet *ta)
 
    int num_upgrades = 0;
    int exit_status = 0;
-   gboolean res = FALSE;
    GError *error;
 
    char *cmd[] = { UPGRADE_CHECKER, NULL };
@@ -302,22 +239,21 @@ update_check (TrayApplet *ta)
       if(ret[0] == 'E') {
 	 gchar *error;
 	 if(strlen(ret) > 3) 
-	    error = g_strdup_printf(_("A error occured, please run "
+	    error = g_strdup_printf(_("An error occurred, please run "
 				      "Package Manager from the "
-				      "right-click menu or apt-get on "
+				      "right-click menu or apt-get in "
 				      "a terminal to see what is wrong.\n"
 				      "The error message was: '%s'"),
 				    &ret[2]);
 	 else
-	    error = g_strdup_printf(_("A error occured, please run "
+	    error = g_strdup_printf(_("An error occurred, please run "
 				      "Package Manager from the "
-				      "right-click menu or apt-get on "
+				      "right-click menu or apt-get in "
 				      "a terminal to see what is wrong."));
-	 gtk_tooltips_set_tip(GTK_TOOLTIPS(ta->tooltip), 
-			      GTK_WIDGET (ta->eventbox), error,
-			      _("This usually means that your installed "
-				"packages have unmet dependencies"));
-	 gtk_widget_show(GTK_WIDGET(ta->tray_icon));
+	 gtk_status_icon_set_tooltip(ta->tray_icon, 
+				   _("This usually means that your installed "
+				     "packages have unmet dependencies"));
+	 gtk_status_icon_set_visible(ta->tray_icon, TRUE);
 	 g_free(ret);
 	 return TRUE;
 	 
@@ -328,8 +264,7 @@ update_check (TrayApplet *ta)
       g_warning("Error launching %s", UPGRADE_CHECKER);
    
    if (num_upgrades == 0) {
-      gtk_widget_hide(GTK_WIDGET(ta->tray_icon));
-      gtk_widget_unrealize (GTK_WIDGET(ta->tray_icon));
+      gtk_status_icon_set_visible (ta->tray_icon, FALSE);
       
       if(priv->active_notification != NULL) {
 	 notify_notification_close(priv->active_notification, NULL);
@@ -340,13 +275,13 @@ update_check (TrayApplet *ta)
 
    // update the tooltip
    update_trayicon_update_tooltip(ta, num_upgrades);
-      
+
    // if we are already visible, skip the rest
-   if(GTK_WIDGET_VISIBLE(GTK_WIDGET(ta->tray_icon))) 
+   if(gtk_status_icon_get_visible (ta->tray_icon))
       return TRUE;
 
    // show the icon
-   gtk_widget_show(GTK_WIDGET(ta->tray_icon));
+   gtk_status_icon_set_visible(ta->tray_icon, TRUE);
 
    // the user does not no notification messages
    if(gconf_client_get_bool(priv->gconf,
@@ -356,10 +291,7 @@ update_check (TrayApplet *ta)
    // show the notification with some delay. otherwise on a login
    // the origin of the window is 0,0 and that looks ugly
    g_timeout_add(5000, show_notification, ta);
-      
-
-   //g_print("upgrades: %i\n", un->num_upgrades);
-
+   
    return TRUE;
 }
 
@@ -376,12 +308,12 @@ update_tray_icon_init(TrayApplet *ta)
 
    // connect the signals we need
    g_signal_connect (G_OBJECT(ta->tray_icon),
-		     "button-release-event",
-		     G_CALLBACK (button_release_cb),
+		     "activate",
+		     G_CALLBACK (activate_cb),
 		     ta);
    g_signal_connect (G_OBJECT(ta->tray_icon),
-		     "button-press-event",
-		     G_CALLBACK (button_press_cb),
+		     "popup-menu",
+		     G_CALLBACK (popup_cb),
 		     ta);
 
    /* Menu initialization */
